[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89143&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89143
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 21:33
Start Date: 09/Apr/18 21:33
Worklog Time Spent: 10m 
  Work Description: lukecwik closed pull request #5066: [BEAM-4014] Fix 
class path for examplesJavaIntegrationTest, also fix conversion error from 
DateTime that independently broke PostCommit.
URL: https://github.com/apache/beam/pull/5066
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/runners/google-cloud-dataflow-java/build.gradle 
b/runners/google-cloud-dataflow-java/build.gradle
index 179b71c01e2..059069c2c82 100644
--- a/runners/google-cloud-dataflow-java/build.gradle
+++ b/runners/google-cloud-dataflow-java/build.gradle
@@ -174,7 +174,7 @@ task examplesJavaIntegrationTest(type: Test) {
   exclude '**/WordCountIT.class'
   exclude '**/WindowedWordCountIT.class'
   maxParallelForks 4
-  classpath = configurations.googleCloudPlatformIntegrationTest
+  classpath = configurations.examplesJavaIntegrationTest
   testClassesDirs = 
files(project(":beam-examples-java").sourceSets.test.output.classesDirs)
   useJUnit { }
 }
diff --git 
a/sdks/java/io/google-cloud-platform/src/test/java/org/apache/beam/sdk/io/gcp/bigtable/BigtableWriteIT.java
 
b/sdks/java/io/google-cloud-platform/src/test/java/org/apache/beam/sdk/io/gcp/bigtable/BigtableWriteIT.java
index f7f05e9a6b4..010bcc40590 100644
--- 
a/sdks/java/io/google-cloud-platform/src/test/java/org/apache/beam/sdk/io/gcp/bigtable/BigtableWriteIT.java
+++ 
b/sdks/java/io/google-cloud-platform/src/test/java/org/apache/beam/sdk/io/gcp/bigtable/BigtableWriteIT.java
@@ -40,6 +40,7 @@
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.List;
 import org.apache.beam.sdk.Pipeline;
 import org.apache.beam.sdk.extensions.gcp.options.GcpOptions;
@@ -50,7 +51,6 @@
 import org.apache.beam.sdk.transforms.ParDo;
 import org.apache.beam.sdk.values.KV;
 import org.hamcrest.Matchers;
-import org.joda.time.DateTime;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -72,7 +72,7 @@
   private static BigtableSession session;
   private static BigtableTableAdminClient tableAdminClient;
   private final String tableId =
-  String.format("BigtableWriteIT-%tF-% Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 2h
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89140&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89140
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 21:29
Start Date: 09/Apr/18 21:29
Worklog Time Spent: 10m 
  Work Description: lukecwik opened a new pull request #5066: [BEAM-4014] 
Fix class path for examplesJavaIntegrationTest, also fix conversion error from 
DateTime that independently broke PostCommit.
URL: https://github.com/apache/beam/pull/5066
 
 
   This fixes post commit break in https://github.com/apache/beam/pull/4964
   
   
   
   Follow this checklist to help us incorporate your contribution quickly and 
easily:
   
- [ ] Make sure there is a [JIRA 
issue](https://issues.apache.org/jira/projects/BEAM/issues/) filed for the 
change (usually before you start working on it).  Trivial changes like typos do 
not require a JIRA issue.  Your pull request should address just this issue, 
without pulling in other changes.
- [ ] Format the pull request title like `[BEAM-XXX] Fixes bug in 
ApproximateQuantiles`, where you replace `BEAM-XXX` with the appropriate JIRA 
issue.
- [ ] Write a pull request description that is detailed enough to 
understand:
  - [ ] What the pull request does
  - [ ] Why it does it
  - [ ] How it does it
  - [ ] Why this approach
- [ ] Each commit in the pull request should have a meaningful subject line 
and body.
- [ ] Run `mvn clean verify` to make sure basic checks pass. A more 
thorough check will be performed on your pull request automatically.
- [ ] If this contribution is large, please file an Apache [Individual 
Contributor License Agreement](https://www.apache.org/licenses/icla.pdf).
   
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 89140)
Time Spent: 1h 50m  (was: 1h 40m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 1h 50m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89086&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89086
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 19:41
Start Date: 09/Apr/18 19:41
Worklog Time Spent: 10m 
  Work Description: lukecwik closed pull request #5063: [BEAM-4014] Fix 
project evaluation order for postcommit.
URL: https://github.com/apache/beam/pull/5063
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/runners/google-cloud-dataflow-java/build.gradle 
b/runners/google-cloud-dataflow-java/build.gradle
index cb3c6a42582..179b71c01e2 100644
--- a/runners/google-cloud-dataflow-java/build.gradle
+++ b/runners/google-cloud-dataflow-java/build.gradle
@@ -34,6 +34,7 @@ 
evaluationDependsOn(":beam-sdks-java-io-google-cloud-platform")
 evaluationDependsOn(":beam-sdks-java-extensions-google-cloud-platform-core")
 evaluationDependsOn(":beam-model-fn-execution")
 evaluationDependsOn(":beam-sdks-java-core")
+evaluationDependsOn(":beam-examples-java")
 
 processResources {
   filter org.apache.tools.ant.filters.ReplaceTokens, tokens: [


 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 89086)
Time Spent: 1h 40m  (was: 1.5h)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 1h 40m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89084&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89084
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 19:41
Start Date: 09/Apr/18 19:41
Worklog Time Spent: 10m 
  Work Description: lukecwik opened a new pull request #5063: [BEAM-4014] 
Fix project evaluation order for postcommit.
URL: https://github.com/apache/beam/pull/5063
 
 
   
   
   
   Follow this checklist to help us incorporate your contribution quickly and 
easily:
   
- [ ] Make sure there is a [JIRA 
issue](https://issues.apache.org/jira/projects/BEAM/issues/) filed for the 
change (usually before you start working on it).  Trivial changes like typos do 
not require a JIRA issue.  Your pull request should address just this issue, 
without pulling in other changes.
- [ ] Format the pull request title like `[BEAM-XXX] Fixes bug in 
ApproximateQuantiles`, where you replace `BEAM-XXX` with the appropriate JIRA 
issue.
- [ ] Write a pull request description that is detailed enough to 
understand:
  - [ ] What the pull request does
  - [ ] Why it does it
  - [ ] How it does it
  - [ ] Why this approach
- [ ] Each commit in the pull request should have a meaningful subject line 
and body.
- [ ] Run `mvn clean verify` to make sure basic checks pass. A more 
thorough check will be performed on your pull request automatically.
- [ ] If this contribution is large, please file an Apache [Individual 
Contributor License Agreement](https://www.apache.org/licenses/icla.pdf).
   
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 89084)
Time Spent: 1.5h  (was: 1h 20m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 1.5h
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89054&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89054
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 17:58
Start Date: 09/Apr/18 17:58
Worklog Time Spent: 10m 
  Work Description: lukecwik closed pull request #5058: [BEAM-4014] Remove 
previous names because this renames the existing job which is a different type 
of job.
URL: https://github.com/apache/beam/pull/5058
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy 
b/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
index ba0da5dab44..ca9059108fd 100644
--- a/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
+++ b/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
@@ -22,8 +22,6 @@ import common_job_properties
 // tests.
 job('beam_PostCommit_Java_GradleBuild') {
   description('Runs PostCommit tests on the Java SDK.')
-  previousNames('beam_PostCommit_MavenVerify')
-  previousNames('beam_PostCommit_Java_MavenInstall')
 
   // Execute concurrent builds if necessary.
   concurrentBuild()


 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 89054)
Time Spent: 1h 20m  (was: 1h 10m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 1h 20m
>  Remaining Estimate: 0h
>




diff --git a/.test-infra/jenkins/job_beam_PreCommit_Java_GradleBuild.groovy 
b/.test-infra/jenkins/job_beam_PreCommit_Java_GradleBuild.groovy
index fe3e1ac76c6..66216708546 100644
--- a/.test-infra/jenkins/job_beam_PreCommit_Java_GradleBuild.groovy
+++ b/.test-infra/jenkins/job_beam_PreCommit_Java_GradleBuild.groovy
@@ -44,7 +44,7 @@ job('beam_PreCommit_Java_GradleBuild') {
 '--continue',
 // Until we verify the build cache is working appropriately, force 
rerunning all tasks
 '--rerun-tasks',
-// Specify maven home on Jenkins
+// Specify maven home on Jenkins, needed by Maven archetype integration 
tests.
 '-Pmaven_home=/home/jenkins/tools/maven/apache-maven-3.5.2'
   ]
 
diff --git a/build.gradle b/build.gradle
index d4ebafe30e7..102fffbe687 100644
--- a/build.gradle
+++ b/build.gradle
@@ -109,7 +109,7 @@ rat {
 }
 check.dependsOn rat
 
-// Define root PreCommit tasks simplifying what is needed
+// Define root pre/post 

[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-08 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=88800&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-88800
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 08/Apr/18 14:26
Start Date: 08/Apr/18 14:26
Worklog Time Spent: 10m 
  Work Description: lukecwik commented on a change in pull request #5047: 
[BEAM-4014] Replace the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047#discussion_r179949535
 
 

 ##
 File path: .test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
 ##
 @@ -20,46 +20,50 @@ import common_job_properties
 
 // This job runs the Java postcommit tests, including the suite of integration
 // tests.
-mavenJob('beam_PostCommit_Java_MavenInstall') {
-  description('Runs postcommit tests on the Java SDK.')
-
+job('beam_PostCommit_Java_GradleBuild') {
 
 Review comment:
   This also runs the other runners as well via the precommit dependency.
   
   Also, I think this is the place where we do want all postcommits to live, 
not just Dataflow specific ones (even though they may be the only ones).


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 88800)
Time Spent: 50m  (was: 40m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
>  Time Spent: 50m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89053&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89053
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 17:55
Start Date: 09/Apr/18 17:55
Worklog Time Spent: 10m 
  Work Description: lukecwik commented on issue #5058: [BEAM-4014] Remove 
previous names because this renames the existing job which is a different type 
of job.
URL: https://github.com/apache/beam/pull/5058#issuecomment-379838591
 
 
   Run Seed Job


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 89053)
Time Spent: 1h 10m  (was: 1h)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
> Fix For: Not applicable
>
>  Time Spent: 1h 10m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-09 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=89005&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-89005
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 09/Apr/18 16:34
Start Date: 09/Apr/18 16:34
Worklog Time Spent: 10m 
  Work Description: lukecwik closed pull request #5047: [BEAM-4014] Replace 
the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/.test-infra/jenkins/job_beam_PostCommit_Java_MavenInstall.groovy 
b/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
similarity index 55%
rename from .test-infra/jenkins/job_beam_PostCommit_Java_MavenInstall.groovy
rename to .test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
index 0dda772a230..ba0da5dab44 100644
--- a/.test-infra/jenkins/job_beam_PostCommit_Java_MavenInstall.groovy
+++ b/.test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
@@ -20,10 +20,10 @@ import common_job_properties
 
 // This job runs the Java postcommit tests, including the suite of integration
 // tests.
-mavenJob('beam_PostCommit_Java_MavenInstall') {
-  description('Runs postcommit tests on the Java SDK.')
-
+job('beam_PostCommit_Java_GradleBuild') {
+  description('Runs PostCommit tests on the Java SDK.')
   previousNames('beam_PostCommit_MavenVerify')
+  previousNames('beam_PostCommit_Java_MavenInstall')
 
   // Execute concurrent builds if necessary.
   concurrentBuild()
@@ -31,35 +31,39 @@ mavenJob('beam_PostCommit_Java_MavenInstall') {
   // Set common parameters.
   common_job_properties.setTopLevelMainJobProperties(delegate, 'master', 240)
 
-  // Set maven parameters.
-  common_job_properties.setMavenConfig(delegate)
+  def gradle_switches = [
+// Gradle log verbosity enough to diagnose basic build issues
+"--info",
+// Continue the build even if there is a failure to show as many potential 
failures as possible.
+'--continue',
+// Until we verify the build cache is working appropriately, force 
rerunning all tasks
+'--rerun-tasks',
+// Specify maven home on Jenkins, needed by Maven archetype integration 
tests.
+'-Pmaven_home=/home/jenkins/tools/maven/apache-maven-3.5.2'
+  ]
+
+  // Publish all test results to Jenkins
+  publishers {
+archiveJunit('**/build/test-results/**/*.xml')
+  }
 
   // Sets that this is a PostCommit job.
   common_job_properties.setPostCommit(delegate)
 
   // Allows triggering this build against pull requests.
   common_job_properties.enablePhraseTriggeringFromPullRequest(
-  delegate,
-  'Java SDK Post Commit Tests',
-  'Run Java PostCommit')
+  delegate,
+  'Java SDK Post Commit Tests',
+  'Run Java PostCommit')
 
-  // Maven goals for this job.
-  goals([
-  'clean',
-  'install',
-  '--projects sdks/java/core,runners/direct-java,sdks/java/fn-execution',
-  ' --also-make',
-  '--also-make-dependents',
-  '--batch-mode',
-  '--errors',
-  '--fail-at-end',
-  '-P release,dataflow-runner',
-  '-DrepoToken=$COVERALLS_REPO_TOKEN',
-  '-D skipITs=false',
-  '''-D integrationTestPipelineOptions=\'[ \
-  "--project=apache-beam-testing", \
-  "--tempRoot=gs://temp-storage-for-end-to-end-tests", \
-  "--runner=TestDataflowRunner" \
-]\' '''
-  ].join(' '))
+  // Gradle goals for this job.
+  steps {
+gradle {
+  rootBuildScriptDir(common_job_properties.checkoutDir)
+  tasks(':javaPostCommit')
+  for (String gradle_switch : gradle_switches) {
+switches(gradle_switch)
+  }
+}
+  }
 }
--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-06 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=88619&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-88619
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 06/Apr/18 21:52
Start Date: 06/Apr/18 21:52
Worklog Time Spent: 10m 
  Work Description: tgroh commented on a change in pull request #5047: 
[BEAM-4014] Replace the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047#discussion_r179884471
 
 

 ##
 File path: .test-infra/jenkins/job_beam_PostCommit_Java_GradleBuild.groovy
 ##
 @@ -20,46 +20,50 @@ import common_job_properties
 
 // This job runs the Java postcommit tests, including the suite of integration
 // tests.
-mavenJob('beam_PostCommit_Java_MavenInstall') {
-  description('Runs postcommit tests on the Java SDK.')
-
+job('beam_PostCommit_Java_GradleBuild') {
 
 Review comment:
   As it exists, this is a Dataflow Java PostCommit, rather than a 
Gradle-target. Perhaps a name change is in order?


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 88619)
Time Spent: 40m  (was: 0.5h)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
>  Time Spent: 40m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-06 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=88614&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-88614
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 06/Apr/18 21:12
Start Date: 06/Apr/18 21:12
Worklog Time Spent: 10m 
  Work Description: lukecwik commented on issue #5047: [BEAM-4014] Replace 
the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047#issuecomment-379381052
 
 
   If #5048 is merged, the project names need to be updated.
   
   CC: @swegner 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 88614)
Time Spent: 0.5h  (was: 20m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
>  Time Spent: 0.5h
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-06 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=88607&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-88607
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 06/Apr/18 20:52
Start Date: 06/Apr/18 20:52
Worklog Time Spent: 10m 
  Work Description: lukecwik commented on issue #5047: [BEAM-4014] Replace 
the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047#issuecomment-379374480
 
 
   CC: @tgroh 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 88607)
Time Spent: 20m  (was: 10m)

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
>  Time Spent: 20m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)


[jira] [Work logged] (BEAM-4014) Migrate MavenInstall Jenkins PostCommits to Gradle

2018-04-06 Thread ASF GitHub Bot (JIRA)

 [ 
https://issues.apache.org/jira/browse/BEAM-4014?focusedWorklogId=88606&page=com.atlassian.jira.plugin.system.issuetabpanels:worklog-tabpanel#worklog-88606
 ]

ASF GitHub Bot logged work on BEAM-4014:


Author: ASF GitHub Bot
Created on: 06/Apr/18 20:51
Start Date: 06/Apr/18 20:51
Worklog Time Spent: 10m 
  Work Description: lukecwik opened a new pull request #5047: [BEAM-4014] 
Replace the Java maven based PostCommit with a Gradle based version.
URL: https://github.com/apache/beam/pull/5047
 
 
   
https://builds.apache.org/view/A-D/view/Beam/job/beam_PreCommit_Java_MavenInstall/19300/testReport/api/json
   shows the list of ITs that were executed. Note that its all the 
examples/java ITs and the sdks/java/io/google-cloud-platform ITs.
   
   
   
   Follow this checklist to help us incorporate your contribution quickly and 
easily:
   
- [ ] Make sure there is a [JIRA 
issue](https://issues.apache.org/jira/projects/BEAM/issues/) filed for the 
change (usually before you start working on it).  Trivial changes like typos do 
not require a JIRA issue.  Your pull request should address just this issue, 
without pulling in other changes.
- [ ] Format the pull request title like `[BEAM-XXX] Fixes bug in 
ApproximateQuantiles`, where you replace `BEAM-XXX` with the appropriate JIRA 
issue.
- [ ] Write a pull request description that is detailed enough to 
understand:
  - [ ] What the pull request does
  - [ ] Why it does it
  - [ ] How it does it
  - [ ] Why this approach
- [ ] Each commit in the pull request should have a meaningful subject line 
and body.
- [ ] Run `mvn clean verify` to make sure basic checks pass. A more 
thorough check will be performed on your pull request automatically.
- [ ] If this contribution is large, please file an Apache [Individual 
Contributor License Agreement](https://www.apache.org/licenses/icla.pdf).
   
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


Issue Time Tracking
---

Worklog Id: (was: 88606)
Time Spent: 10m
Remaining Estimate: 0h

> Migrate MavenInstall Jenkins PostCommits to Gradle
> --
>
> Key: BEAM-4014
> URL: https://issues.apache.org/jira/browse/BEAM-4014
> Project: Beam
>  Issue Type: Sub-task
>  Components: build-system, testing
>Reporter: Henning Rohde
>Assignee: Luke Cwik
>Priority: Major
>  Time Spent: 10m
>  Remaining Estimate: 0h
>




--
This message was sent by Atlassian JIRA
(v7.6.3#76005)